"""
Pythonic built-in functions for Dana.

This module provides Pythonic built-in functions (like len, sum, max, min, etc.)
for the Dana language using a central dispatch approach.

Copyright © 2025 Aitomatic, Inc.
MIT License
"""

# Functions are now loaded directly in dana.libs.corelib.__init__.py
