"""MCP (Model Context Protocol) Integration."""

# Import core MCP resource
# Import A2A (Agent-to-Agent) components
from .mcp_resource import MCPResource

__all__ = [
    # Core MCP
    "MCPResource",
]
